@@ -860,24 +860,21 @@ asn1_number_of_elements(ASN1_TYPE element,const char *name,int *num)
   * after an OID definition.
   * @definitions: ASN1 definitions
   * @oidValue: value of the OID to search (e.g. "1.2.3.4").
-  * @structureName: name returned by the function, that is the structure 
-  * defined just after the OID of value equal to OIDVALUE.
-  * It must be an array of MAX_NAME_SIZE char elements.
-  * 
   * Description:
   *
   * Search the structure that is defined just after an OID definition.
   *
   * Returns:
   *
-  *   ASN1_SUCCESS\: structure found.
+  *   NULL when OIDVALUE not found,
   *
-  *   ASN1_ELEMENT_NOT_FOUND\: OID equal to OIDVALUE not found.
+  *   otherwise the pointer to a constant string that contains the element 
+  *   name defined just after the OID.
   *
   **/
-asn1_retCode
+const char*
 asn1_find_structure_from_oid(ASN1_TYPE definitions,
-                         const char *oidValue,char *structureName)
+                         const char *oidValue)
 {
   char definitionsName[MAX_NAME_SIZE],name[2*MAX_NAME_SIZE+1];
   char value[MAX_NAME_SIZE];
@@ -886,7 +883,7 @@ asn1_find_structure_from_oid(ASN1_TYPE definitions,
   asn1_retCode result;
 
   if((definitions==ASN1_TYPE_EMPTY) || (oidValue==NULL))
-    return ASN1_ELEMENT_NOT_FOUND;
+    return NULL;  /* ASN1_ELEMENT_NOT_FOUND; */
 
 
   strcpy(definitionsName,definitions->name);
@@ -906,16 +903,15 @@ asn1_find_structure_from_oid(ASN1_TYPE definitions,
       if((result == ASN1_SUCCESS) && (!strcmp(oidValue,value))){
 	p=p->right;
 	if(p==NULL)  /* reach the end of ASN1 definitions */
-	  return ASN1_ELEMENT_NOT_FOUND;
+	  return NULL;   /* ASN1_ELEMENT_NOT_FOUND; */
 	
-	strcpy(structureName,p->name);
-	return ASN1_SUCCESS;
+	return p->name;
       }
     }
     p=p->right;
   }
 
-  return ASN1_ELEMENT_NOT_FOUND;
+  return NULL;  /* ASN1_ELEMENT_NOT_FOUND; */
 }
 
 
