@@ -69,6 +69,26 @@ test_type test_array[]={
 
   {ACT_DELETE,"","",0,ASN1_ELEMENT_NOT_FOUND},
 
+  /* Test: OID and TIME */
+  {ACT_CREATE,"TEST_TREE.OidAndTimeTest",0,0,ASN1_SUCCESS},
+  {ACT_WRITE,"oid","1.2.3.4",0,ASN1_SUCCESS},
+  {ACT_WRITE,"time1","9801011200Z",1,ASN1_SUCCESS},
+  {ACT_WRITE,"time2","2001010112001.12-0700",1,ASN1_SUCCESS},
+  {ACT_WRITE,"oct","ABCD",4,ASN1_SUCCESS},
+  {ACT_READ_LENGTH,"oid",NULL,8,ASN1_MEM_ERROR},
+  {ACT_READ_LENGTH,"time1",NULL,12,ASN1_MEM_ERROR},
+  {ACT_READ_LENGTH,"time2",NULL,22,ASN1_MEM_ERROR},
+  {ACT_READ_LENGTH,"oct",NULL,4,ASN1_MEM_ERROR},
+  {ACT_ENCODING_LENGTH,"",0,49,ASN1_MEM_ERROR},
+  {ACT_ENCODING,"",0,48,ASN1_MEM_ERROR},
+  {ACT_ENCODING,"",0,200,ASN1_SUCCESS},
+  {ACT_PRINT_DER,0,0,0,ASN1_SUCCESS},
+  {ACT_DELETE,"","",0,ASN1_SUCCESS},
+  {ACT_CREATE,"TEST_TREE.OidAndTimeTest",0,0,ASN1_SUCCESS},
+  {ACT_DECODING,0,0,0,ASN1_SUCCESS},
+  {ACT_VISIT,"","",ASN1_PRINT_ALL,ASN1_SUCCESS},
+  {ACT_DELETE,"","",0,ASN1_SUCCESS},
+
   /* Test: OID to STRUCTURE */
   {ACT_OID_2_STRUCTURE,"2.5.29.3","",0,ASN1_ELEMENT_NOT_FOUND},
   {ACT_OID_2_STRUCTURE,"1.2.29.2","",0,ASN1_ELEMENT_NOT_FOUND},
@@ -253,6 +273,7 @@ main(int argc,char *argv[])
   int valueLen,tag=0,class=0;
   int k;
   int start,end;
+  const char *str_p=NULL;
 
   printf("\n\n/****************************************/\n");
   printf(    "/*     Test sequence : Test_tree        */\n");
@@ -351,7 +372,7 @@ main(int argc,char *argv[])
                                       test->par2);
       break;
     case ACT_OID_2_STRUCTURE:
-      result=asn1_find_structure_from_oid(definitions,test->par1,value);
+      str_p=asn1_find_structure_from_oid(definitions,test->par1);
       break;
     case ACT_VISIT:
       asn1_print_structure(out,asn1_element,test->par1,test->par3);
@@ -430,15 +451,14 @@ main(int argc,char *argv[])
       }
       break;
     case ACT_OID_2_STRUCTURE:
-      if((result != test->errorNumber) ||
-	 ((result == ASN1_SUCCESS) && (strcmp(value,test->par2)))){
+      if(((test->errorNumber!=ASN1_SUCCESS) && (str_p!=NULL)) ||
+	 ((test->errorNumber==ASN1_SUCCESS) && (str_p==NULL)) ||
+	 ((test->errorNumber==ASN1_SUCCESS) && (strcmp(str_p,test->par2)))){
 	errorCounter++;
 	printf("ERROR N. %d:\n",errorCounter);
 	printf("  Action %d - %s\n",test->action,test->par1);
-	printf("  Error expected: %s - %s\n",libtasn1_strerror(test->errorNumber),
-                                             test->par2);
-	printf("\n  Error detected: %s - %s\n\n",libtasn1_strerror(result),
-                                          value);
+	printf("  Error expected: %s - %s\n",libtasn1_strerror(test->errorNumber),test->par2);
+	printf("  Value detected: %s\n\n",str_p);
       }
       break;
     case ACT_DECODING_START_END:
